import stamp.core.*;  //Core software
import stamp.peripheral.adc.*;  //Analogue to Digital Class for accelerometer
import stamp.peripheral.gps.*;  //GPS Class for location and navigation
import stamp.peripheral.ping.*;  //PING Class - two instances required for front and back


//CarMain.. Always running on the system
public class CarMain {

  //Need to keep track of the status?
  //static int status_steer = 5;
  //New way of steering, left arrow key and right arrow key????

  //pins for serial comms back to base station
  final static int SERIAL_TX_PIN = CPU.pin0;  //Serial Pin 2
  final static int SERIAL_RX_PIN = CPU.pin1;  //Serial Pin 3
  static Uart txBaseStation = new Uart( Uart.dirTransmit, SERIAL_TX_PIN, Uart.dontInvert, Uart.speed9600, Uart.stop1 );
  static Uart rxBaseStation = new Uart( Uart.dirReceive, SERIAL_RX_PIN, Uart.dontInvert, Uart.speed9600, Uart.stop1 );
  static StringBuffer buffer = new StringBuffer(128);

  //pins for GPS data from chip to stamp
  static Uart sio = new Uart(Uart.dirReceive,CPU.pin15,Uart.dontInvert,Uart.speed4800,Uart.stop1);
  static GPS_Parallax mygps = new GPS_Parallax(sio,0);

  //pins for vehicle PWM
  static PWM steering = new PWM(CPU.pin12,173,2304);
  static PWM engine = new PWM(CPU.pin13,173,2304);

  //Pins for Accelerometer chip.. two for each axis (will need another when can afford 3 axis chip)
  static Accelerometer accChip = new Accelerometer(CPU.pin9, CPU.pin8,CPU.pin11, CPU.pin10);

  //Need some kind of code for compass????

  //Pins for PING Sonar.. for now just focus on the forward bracket
  static Ping range = new Ping(CPU.pin5);

  //Right.. now the main code that just executes unless new command received.
  //Need to ensure that information is constantly being fed back to the base station
  public static void main() {

      buffer.clear();
      txBaseStation.sendString("Steering Control: \n\r");
      txBaseStation.sendString("r - right \n\r");
      txBaseStation.sendString("l - left \n\r");
      txBaseStation.sendString("c - center \n\r\n\r");
      txBaseStation.sendString("Engine Control: \n\r");
      txBaseStation.sendString("1 - ForwardGear1 \n\r");
      txBaseStation.sendString("2 - ForwardGear2 \n\r");
      txBaseStation.sendString("3 - ForwardGear3 \n\r");
      txBaseStation.sendString("4 - ForwardGear4 \n\r");
      txBaseStation.sendString("f - MaxForward \n\r");
      txBaseStation.sendString("6 - BackwardGear1 \n\r");
      txBaseStation.sendString("7 - BackwardGear2 \n\r");
      txBaseStation.sendString("8 - BackwardGear3 \n\r");
      txBaseStation.sendString("9 - BackwardGear4 \n\r");
      txBaseStation.sendString("s - stops \n\r\n\r");
      txBaseStation.sendString("Status: \n\r");
      txBaseStation.sendString("g - GPS Data \n\r");

      while (true) {

      switch ( rxBaseStation.receiveByte() ) {
      case 'r':
        steering.update(220,2304);
        break;
      case 'l':
        steering.update(130,2304);
        break;
      case 'c':
        steering.update(173,2304);
        break;
      case 'f':
        engine.update(220,2304);
        break;
      case '1':
        engine.update(177,2304);
        break;
      case '2':
        engine.update(178,2304);
        break;
      case '3':
        engine.update(179,2304);
        break;
      case '4':
        engine.update(180,2304);
        break;
      case 'b':
        engine.update(130,2304);
        break;
      case '6':
        engine.update(169,2304);
        break;
      case '7':
        engine.update(168,2304);
        break;
      case '8':
        engine.update(167,2304);
        break;
      case '9':
        engine.update(166,2304);
        break;
      case 's':
        engine.update(173,2304);
        break;
      case 'g':
        txBaseStation.sendString("Latitude: " + mygps.latDegrees + " " + mygps.latMinutes + "' " + mygps.latFracmin + " - " + mygps.latDirection + "\n\r");
        txBaseStation.sendString("Longitude: " + mygps.lngDegrees + " " + mygps.lngMinutes + "' " + mygps.lngFracmin + " - " + mygps.lngDirection + "\n\r");
        break;
      }
    }


      //c = (char) rxUart.receiveByte();
   //} while(c == 'y' || c != 'n');
   //txUart.sendString("Platform Control Regained\n\r");

  }
}